/*******************(C) COPYRIGHT 2019 GRAND-LOTUS ******************************************
;* File Name          : PWM0_INIT.C
;* Author             : GRAND LOTUS
;* Version            : V1.00
;* Date               : 2019/07/01
*********************************************************************************************
;
;PWM0初始化程序
;
********************************************************************************************/

#include "common.h"
//******************************************************************************************
/////////////////////T0CR 控制寄存器各位定义////////////////////////////////////////////////
//******************************************************************************************
//TxCR 定时器控制寄存器
//TCxEN:  TCx模块使能位
//1 = 使能TCx
//0 = 关闭TCx
//TCxMOD:  TCx模式选择位
//1 = 16位模式
//0 = 8位模式
//TCxCKS:  TCx时钟源选择
//TCxCKS[1:0]	TCx时钟源选择
//00	Foscl(低频系统时钟)
//01	Fosch(高频系统时钟)
//10	Fcpu
//11	TC0:(T0cki) TC1:(TK)
//TCxCKPS[2:0]:  TCx预分频比选择
//TCxCKPS[2:0]	TCx预分频比
//000	1:1
//001	1:2
//010	1:4
//011	1:8
//100	1:16
//101	1:32
//110	1:64
//111	1:128
#define		TC0EN_1					Bin(10000000)             			//使能TC0			
#define   	TC0EN_0     			Bin(00000000)						//屏蔽TC0
#define	  	TC0MOD_16				Bin(01000000)						//16位模式
#define	  	TC0MOD_8				Bin(00000000)						//8位模式
#define		TC0CKS_Foscl			Bin(00000000)						//Foscl(低频系统时钟)
#define		TC0CKS_Fosch			Bin(00001000)						//Fosch(高频系统时钟)
#define		TC0CKS_Fcpu				Bin(00010000)						//Fcpu
#define		TC0CKPS_1_1				Bin(00000000)						//分频比1：1
#define		TC0CKPS_1_2				Bin(00000001)						//分频比1：2
#define		TC0CKPS_1_4				Bin(00000010)						//分频比1：4
#define		TC0CKPS_1_8				Bin(00000011)						//分频比1：8
#define		TC0CKPS_1_16			Bin(00000100)						//分频比1：16
#define		TC0CKPS_1_32			Bin(00000101)						//分频比1：32
#define		TC0CKPS_1_64			Bin(00000110)						//分频比1：64
#define		TC0CKPS_1_128			Bin(00000111)						//分频比1：128
//******************************************************************************************
///////////////////////////////PWM0CR控制寄存器各位定义/////////////////////////////////////
//******************************************************************************************
//Bit 7 		PWM0EN:  PWM模块使能位
//1 = 使能PWM
//0 = 关闭PWM
//Bit 6 		PWM0OE:  PWM波形输出使能位
//1 = 端口输出PWM波形
//0 = 端口用作IO
//Bit 2 		PWM0TBS:  PWM时基选择
//1 = 定时器1
//0 = 定时器0
#define		PWM0EN_1				Bin(10000000)						//使能PWM
#define   	PWM0EN_0     			Bin(00000000)						//关闭PWM
#define		PWM0OE_1				Bin(01000000)						//端口输出PWM波形
#define		PWM0OE_0				Bin(00000000)						//端口用作IO
#define		PWM0TBS_1				Bin(00000100)						//PWM时基选择定时器1
#define		PWM0TBS_0				Bin(00000000)						//PWM时基选择定时器0

//******************************************************************************************
//*********************************PWM0_Demo程序********************************************
//******************************************************************************************
void PWM0_Init(void)
{
//1、IO端口设置
	OEB0 = 1;														   			  //PWM0的输出端口为IOB0
//2、时钟源设置(以TC0为例,使其产生1k的波形)
	T0CR = (unsigned char) (TC0MOD_8+TC0CKS_Fosch+TC0CKPS_1_64);	             //定时器T0，8位Fosch，频分比1：64	
	TC0CH = 0;
	TC0CL = 249;																//16M/64/125=1KHz		
//3、PWM设置
	PWM0CR = (unsigned char) (PWM0OE_1+PWM0TBS_0);						        //PWM时基选择定时器T0
	PWM0D	=	(249+1)/2;													   //输出波形占空比为1：1
//4、开启PWM0	
	TC0EN = 1;																  //定时器	T0开启
	PWM0EN = 1;																  //PWM0开启
}	
/*********************************END OF FILE*************************************************/ 
